aboutsummaryrefslogtreecommitdiffstats
path: root/color_filters.h
diff options
context:
space:
mode:
authorGerald Combs <gerald@wireshark.org>2015-02-04 16:36:19 -0800
committerGerald Combs <gerald@wireshark.org>2015-02-07 00:30:30 +0000
commitc8cad99515eeac25faf6ea84795ce6b5fa4afebb (patch)
treeec72051d71ac3caf9331690a6f34d6255a876576 /color_filters.h
parentb3f3dd8d82d9b651f34886a3293056c612958aa2 (diff)
Qt: Add the Coloring Rules dialog.
Merge in the old ColorDialog which was a placeholder for color_filter_add_cb. Change-Id: I48d188509f480b8514122b4011ac9d8790fcca10 Reviewed-on: https://code.wireshark.org/review/6996 Petri-Dish: Gerald Combs <gerald@wireshark.org> Tested-by: Petri Dish Buildbot <buildbot-no-reply@wireshark.org> Reviewed-by: Gerald Combs <gerald@wireshark.org>
Diffstat (limited to 'color_filters.h')
-rw-r--r--color_filters.h13
1 files changed, 4 insertions, 9 deletions
diff --git a/color_filters.h b/color_filters.h
index e8262d85b4..7fe8068011 100644
--- a/color_filters.h
+++ b/color_filters.h
@@ -40,13 +40,13 @@ typedef struct _color_filter {
color_t bg_color; /* background color for packets that match */
color_t fg_color; /* foreground color for packets that match */
gboolean disabled; /* set if the filter is disabled */
- gboolean selected; /* set if the filter is selected in the color dialog box */
+ gboolean selected; /* set if the filter is selected in the color dialog box. GTK+ only. */
/* only used inside of color_filters.c */
struct epan_dfilter *c_colorfilter; /* compiled filter expression */
/* only used outside of color_filters.c (beside init) */
- void *color_edit_dlg_info; /* if filter is being edited, ptr to req'd info */
+ void *color_edit_dlg_info; /* if filter is being edited, ptr to req'd info. GTK+ only. */
} color_filter_t;
@@ -120,7 +120,7 @@ void color_filters_clone(gpointer user_data);
* @param user_data will be returned by each call to to color_filter_add_cb()
* @return TRUE, if read succeeded
*/
-gboolean color_filters_import(gchar *path, gpointer user_data);
+gboolean color_filters_import(const gchar *path, const gpointer user_data);
/** Read filters from the global filter file (not the users file).
*
@@ -160,9 +160,7 @@ gboolean color_filters_write(GSList *cfl);
* @param only_selected TRUE if only the selected filters should be saved
* @return TRUE, if write succeeded
*/
-gboolean color_filters_export(gchar *path, GSList *cfl, gboolean only_selected);
-
-
+gboolean color_filters_export(const gchar *path, const GSList *cfl, gboolean only_selected);
/** Create a new color filter (g_malloc'ed).
*
@@ -183,9 +181,6 @@ color_filter_t *color_filter_new(
*/
void color_filter_delete(color_filter_t *colorf);
-
-
-
/** Delete a filter list including all entries.
*
* @param cfl the filter list to delete